@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -10,10 +10,11 @@ from ...config import (
     PRIVATE_GET_DEPOSIT_METADATA,
     PRIVATE_GET_RAW_CONTENT,
     PRIVATE_LIST_DEPOSITS,
+    PRIVATE_LIST_DEPOSITS_DATATABLES,
     PRIVATE_PUT_DEPOSIT,
 )
 from .deposit_check import APIChecks
-from .deposit_list import APIList
+from .deposit_list import APIList, deposit_list_datatables
 from .deposit_read import APIReadArchives, APIReadMetadata
 from .deposit_update_status import APIUpdateStatus
 
@@ -75,4 +76,9 @@ urlpatterns = [
         name=PRIVATE_CHECK_DEPOSIT + "-nc",
     ),
     url(r"^deposits/$", APIList.as_view(), name=PRIVATE_LIST_DEPOSITS),
+    url(
+        r"^deposits/datatables/$",
+        deposit_list_datatables,
+        name=PRIVATE_LIST_DEPOSITS_DATATABLES,
+    ),
 ]
