@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -27,6 +27,7 @@ PRIVATE_CHECK_DEPOSIT = "check-deposit"
 PRIVATE_PUT_DEPOSIT = "private-update"
 PRIVATE_GET_DEPOSIT_METADATA = "private-read"
 PRIVATE_LIST_DEPOSITS = "private-deposit-list"
+PRIVATE_LIST_DEPOSITS_DATATABLES = "private-deposit-list-datatables"
 
 ARCHIVE_KEY = "archive"
 RAW_METADATA_KEY = "raw-metadata"
@@ -110,8 +111,12 @@ class APIConfig:
 
     def swh_deposit_authority(self):
         return MetadataAuthority(
-            type=MetadataAuthorityType.REGISTRY, url=self.config["swh_authority_url"],
+            type=MetadataAuthorityType.REGISTRY,
+            url=self.config["swh_authority_url"],
         )
 
     def swh_deposit_fetcher(self):
-        return MetadataFetcher(name=self.tool["name"], version=self.tool["version"],)
+        return MetadataFetcher(
+            name=self.tool["name"],
+            version=self.tool["version"],
+        )
